<form action="/search" method="get">
    <input type="text" class="search" placeholder="<?= $this->lang->line('Search') ?>" name="search_text" value="<?= $this->input->get('search_text') ?>" maxlength="60">
    <input type="submit" class="search_button">
</form>